# Create an ADIF file suitable for import into LOGic to assist in contest 
# data analysis
#
# To my knowledge, the ADIF standard has no items for QTCs and relies
# on individaul programs to create application specific items.
# N1MM does not include QTCs in its ADIF output, but does include them in
# the Cabrillo output.
# 
# LOGic treats QTCs in a different way to N1MM.
#		N1MM creates separate record for each QTC.
#		LOGic asks one to update the QSO to indictae it was reported in a QTC
#
# NOTE:   There is an omission in LOGic as installed, in that it does not 
# record the "time the QTC was sent".  This is required as part of any log
# submission.  This is easily corected by adding a WAE_QTCTIME field to the 
# contest form definition.  But ...
#
# NOTE:  Because of the way LOGic stores the QTC material with the QSO, 
# creating a Cabrillo template to create a Cabrillo log WITH QTCs for any log 
# submission is difficult.  I wonder what happens to the points for the 
# other party if my QTCs are not reported in the log I submit?
#
# The purpose of the code is to merge the QTC data from the Cabrillo output of
# N1MM into the ADIF output from N1MM.  This will allow use of the normal ADIF
# import process in LOGic 9.
#
# The GAWK language processor for Windows is readily available on the Internet.
#
BEGIN {
	FS=" " # This sequence separates adif items we care about (Comment/Note item???)
print "<EOH>"
print ""
	
}

/^ <CALL:/ { # Found a QSO, extract the call for an index, keep the data in an array
	QSOS++
	index4qtc = substr($1,index($1,">")+1)
	adiflog[index4qtc]=$0
	qso[QSOS]=index4qtc # create an index to make sure we print in QSO order for LOGic.
}

# Now process the QTCs added to the end of the ADIF log exported from N1MM.
# The QTCs are in the Cabrillo output from N1MM - space separated.
/^QTC:/ {
	FS=" "
	split($7,QTCset,"/")
	adiflog[$10]=substr(adiflog[$10],1,length(adiflog[$10])-5) " <WAE_QTCTO:" length($6) ">" $6 " <WAE_QTCSEQ:" length(QTCset[1]) ">" QTCset[1] " <WAE_QTCCNT:" length(QTCset[2]) ">" QTCset[2]  " <WAE_QTCTIME:" length($9) ">" $9 " <EOR>"
	QTCS++
}
END {
	for (i=1; i <= QSOS; i++) {
	print adiflog[qso[i]]
	}
	# Use the following to check for correct processing.  Comment out for the final run.
	#print "End: " QSOS " QSOs and " QTCS " QTCs"
}